@@ -1,2 +1,2 @@
-from EEETools.Tools.main_tools import calculate, launch_connection_debug
 from EEETools.Tools.main_tools import paste_default_excel_file, paste_components_documentation, paste_user_manual
+from EEETools.Tools.main_tools import calculate, launch_connection_debug, launch_network_display
\ No newline at end of file
